@@ -5,7 +5,7 @@
 **
 ** Comments: Generic datalink module
 **
-** $Id: datalink.c,v 1.23 2001/11/15 00:22:36 mborella Exp $
+** $Id: datalink.c,v 1.25 2002/01/04 17:24:38 mborella Exp $
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -71,8 +71,9 @@ strmap_t datalink_type_map[] =
 
 void datalink_pcap(u_char * user, const struct pcap_pkthdr * h, u_char * pkt)
 {
-  int         linktype = -1;
-  u_int32_t * link;
+  int            linktype = -1;
+  u_int32_t *    link;
+  struct timeval tv;
 
   /* Translate the link type */
   link = (u_int32_t *) user;
@@ -102,9 +103,17 @@ void datalink_pcap(u_char * user, const struct pcap_pkthdr * h, u_char * pkt)
     default:
       error_fatal("\ncannot handle data link type %d", link);
     }
-    
+
+  /* 
+   * Copy the timestamp our own timeval struct to avoid compilation 
+   * errors with older versions of libpcap.
+   */
+  
+  tv.tv_sec = h->ts.tv_sec;
+  tv.tv_usec = h->ts.tv_usec;
+
   /* Call the generic datalink function */
-  datalink(linktype, h->ts, h->caplen, h->len, pkt);
+  datalink(linktype, tv, h->caplen, h->len, pkt);
 }
 
 /*----------------------------------------------------------------------------
@@ -146,8 +155,8 @@ void datalink(int linktype, struct timeval ts, u_int32_t captured_length,
   packet.end = &packet.contents[0] + captured_length;
   packet.apparent_end = packet.end;
   packet.media_length = media_length;
-  sprintf(packet.timestamp, "%u.%06u", (u_int32_t) ts.tv_sec, 
-	  (u_int32_t) ts.tv_usec);
+  snprintf(packet.timestamp, PACKET_TIMESTAMP_LEN, "%u.%06u", 
+	   (u_int32_t) ts.tv_sec, (u_int32_t) ts.tv_usec);
 
   /*
    * If we're in minimal mode, start off with the count number
