@@ -5,7 +5,7 @@
 **
 ** Comments: Dump DHCP header information.  See RFCs 2131 and 2132.
 **
-** $Id: dhcp.c,v 1.14 2001/10/19 15:24:56 mborella Exp $
+** $Id: dhcp.c,v 1.15 2002/01/03 00:04:01 mborella Exp $
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -26,6 +26,8 @@
 #include "arp.h"
 #include "dhcp.h"
 
+#define HOLDER_SIZE 256
+
 /*
  * DHCP operation type map
  */
@@ -127,7 +129,7 @@ void dump_dhcp(packet_t *pkt)
   u_int32_t i;
   u_int32_t cookie_holder;
   u_int8_t opt;
-  char holder[256]; /* this needs to be as big as the biggest option */
+  char holder[HOLDER_SIZE]; /* this needs to be as big as the biggest option */
 
   /* Set the layer */
   set_layer(LAYER_APPLICATION);
@@ -155,7 +157,8 @@ void dump_dhcp(packet_t *pkt)
    * Display operation, other info
    */
 
-  sprintf(holder, "%d (%s)", dhcp.op, map2str(dhcp_op_map, dhcp.op));
+  snprintf(holder, HOLDER_SIZE, "%d (%s)", dhcp.op, 
+	  map2str(dhcp_op_map, dhcp.op));
   if (my_args->m)
     {
       display_minimal_string(map2str(dhcp_op_map, dhcp.op));
@@ -227,7 +230,8 @@ void dump_dhcp(packet_t *pkt)
       
       if (get_packet_bytes((u_int8_t *) &opt, pkt, 1) == 0)
 	return;
-      sprintf(holder, "%d (%s)", opt, map2str(dhcp_option_map, opt));
+      snprintf(holder, HOLDER_SIZE, "%d (%s)", opt, 
+	      map2str(dhcp_option_map, opt));
       if (!my_args->m)
 	display("Option", (u_int8_t *) holder, strlen(holder), DISP_STRING);
       
@@ -317,16 +321,19 @@ void dump_dhcp(packet_t *pkt)
 	  switch(holder[0])
 	    {
 	    case 0x1: 
-	      sprintf(holder, "0x%x (B-node / broadcast)", holder[0]);
+	      snprintf(holder, HOLDER_SIZE, "0x%x (B-node / broadcast)", 
+		       holder[0]);
 	      break;
 	    case 0x2:
-	      sprintf(holder, "0x%x (P-node / point to point)", holder[0]);
+	      snprintf(holder, HOLDER_SIZE, "0x%x (P-node / point to point)", 
+		      holder[0]);
 	      break;
 	    case 0x4:
-	      sprintf(holder, "0x%x (M-node / mixed)", holder[0]);
+	      snprintf(holder, HOLDER_SIZE, "0x%x (M-node / mixed)", 
+		       holder[0]);
 	      break;
 	    case 0x8:
-	      sprintf(holder, "0x%x (H-node)", holder[0]);
+	      snprintf(holder, HOLDER_SIZE, "0x%x (H-node)", holder[0]);
 	      break;
 	    }
 	  if (!my_args->m)
@@ -358,7 +365,7 @@ void dump_dhcp(packet_t *pkt)
 
 	    if (get_packet_bytes(&msg_type, pkt, 1) == 0)
 	      return;
-	    sprintf(holder, "%d (%s)", msg_type, 
+	    snprintf(holder, HOLDER_SIZE, "%d (%s)", msg_type, 
 		    map2str(dhcp_msgtype_map, msg_type));
 	    if (!my_args->m)
 	      display_string("  Message type", holder);
@@ -386,7 +393,7 @@ void dump_dhcp(packet_t *pkt)
 		return;
 	      if (!my_args->m)
 		{
-		  sprintf(holder, "%d (%s)", opt, 
+		  snprintf(holder, HOLDER_SIZE, "%d (%s)", opt, 
 			  map2str(dhcp_option_map, opt));
 		  display_string("  Option", holder);
 		}
@@ -441,7 +448,7 @@ void dump_dhcp(packet_t *pkt)
 	      /* The first byte should be a hardware type */
 	      if (get_packet_bytes((u_int8_t *) &hw_type, pkt, 1) == 0)
 		return;
-	      sprintf(holder, "%d (%s)", hw_type, 
+	      snprintf(holder, HOLDER_SIZE, "%d (%s)", hw_type, 
 		      map2str(arp_hardware_map, hw_type));
 	      display_string("  Hardware type", (u_int8_t *) holder);
 
