@@ -5,7 +5,7 @@
 **
 ** Comments: Displaying functions
 **
-** $Id: display.c,v 1.26 2001/11/15 00:22:36 mborella Exp $
+** $Id: display.c,v 1.27 2002/01/03 00:04:01 mborella Exp $
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -437,7 +437,7 @@ inline void display_strmap(char * label, int content, strmap_t map[])
 {
   char holder[HOLDER_LEN];
 
-  sprintf(holder, "%d (%s)", content, map2str(map, content));
+  snprintf(holder, HOLDER_LEN, "%d (%s)", content, map2str(map, content));
   holder[HOLDER_LEN-1] = '\0';
   display_string(label, holder);
 }
@@ -457,7 +457,7 @@ inline void display_strmap_hex(char * label, int content, strmap_t map[])
 {
   char holder[HOLDER_LEN];
 
-  sprintf(holder, "0x%x (%s)", content, map2str(map, content));
+  snprintf(holder, HOLDER_LEN, "0x%x (%s)", content, map2str(map, content));
   holder[HOLDER_LEN-1] = '\0';
   display_string(label, holder);
 }
