@@ -10,7 +10,7 @@
 ** considered permanent.  Mappings that are made by protocols will time out 
 ** in DYNPORTS_DURATION seconds unless they are refreshed.  
 **
-** $Id: dynports.c,v 1.6 2001/10/11 22:03:38 mborella Exp $
+** $Id: dynports.c,v 1.7 2002/01/02 18:16:39 mborella Exp $
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -28,9 +28,9 @@
 **
 *****************************************************************************/
 
-#include "global.h"
-#include "error.h"
 #include "dynports.h"
+#include "error.h"
+#include "limits.h"
 
 #define DYNPORTS_NUM      256/* max number of dynamic ports on the system */
 #define DYNPORTS_DURATION 5  /* # of seconds that nonpermanent mappings stay */
