@@ -10,7 +10,7 @@
 ** (if any) used for this SA.  But that info is part of the ISAKMP
 ** negotiation rather than the ESP header.  Oh well.
 **
-** $Id: esp.c,v 1.4 2001/04/02 17:41:01 mborella Exp $
+** $Id: esp.c,v 1.5 2001/05/28 19:24:04 mborella Exp $
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -46,6 +46,9 @@ void dump_esp(packet_t *pkt)
 {
   esp_header_t esp;
 
+  /* Set the layer */
+  set_layer(LAYER_NETWORK);
+
   /*
    * Stats accounting
    */
@@ -70,19 +73,18 @@ void dump_esp(packet_t *pkt)
    * Dump header
    */
 
-  if (my_args->m && !my_args->n)
+  if (my_args->m)
     {
       display_minimal((u_int8_t *) &esp.spi, 4, DISP_HEX); 
       display_minimal_string(" ");
     }
   else
-    if (!my_args->n)
-      {
-        /* announcement */
-        display_header_banner("ESP Header");
-	display("SPI", (u_int8_t *) &esp.spi, 4, DISP_HEX); 
-        display("Sequence number", (u_int8_t *) &esp.seqno, 4, DISP_DEC);
-      }
+    {
+      /* announcement */
+      display_header_banner("ESP Header");
+      display("SPI", (u_int8_t *) &esp.spi, 4, DISP_HEX); 
+      display("Sequence number", (u_int8_t *) &esp.seqno, 4, DISP_DEC);
+    }
 
 }
 
