@@ -96,6 +96,7 @@ void dump_ftpctrl(packet_t *pkt)
 	    {
 	      display_minimal_string("FTP control ");
 	      display_minimal_string(replycode_str);
+              display_minimal_string(payload+3);
 	    }
 	  else
 	    {
@@ -110,6 +111,7 @@ void dump_ftpctrl(packet_t *pkt)
 	  if (my_args->m)
 	    {
 	      display_minimal_string("FTP control ");
+              display_minimal_string(payload+3);
 	    }
 	  else
 	    {
@@ -144,6 +146,8 @@ void dump_ftpctrl(packet_t *pkt)
 	{
 	  display_minimal_string("FTP control ");
 	  display_minimal_string(requestcode_str);
+          display_minimal_string(" ");
+          display_minimal_string(ptr+1);
 	}
       else
 	{
