@@ -202,6 +202,43 @@ void dump_ip(packet_t *pkt)
 
 }
 
+/*----------------------------------------------------------------------------
+**
+** dump_ip_recordroute()
+**
+** Dump a record route IP option
+**
+**----------------------------------------------------------------------------
+*/
+
+void dump_ip_recordroute(u_int8_t * rr, u_int8_t len)
+{
+  u_int8_t   pointer;
+  u_int32_t  addr;
+  int        i;
+
+  /*
+   * The first byte should be a pointer and the next len-1 bytes should be 
+   * a series of IP addresses.  If len-1 is not a multiple of 4 then something
+   * is very wrong and we bail out.
+   */
+
+  pointer = *rr;
+  if (!my_args->m)
+    {
+      display("  Pointer", (u_int8_t *) &pointer, 1, DISP_HEX);
+    }
+
+  i = 1;
+  while (i+3 <= len)
+    {
+      /* Get and address then increment i to the next address */
+      memcpy((u_int8_t *) &addr, rr+i, 4);
+      display_ipv4("  Address", (u_int8_t *) &addr);
+      i = i + 4;
+    }
+}
+
 /*----------------------------------------------------------------------------
 **
 ** dump_ip_options()
@@ -266,7 +303,20 @@ void dump_ip_options(packet_t *pkt, u_int8_t length)
       
       if (get_packet_bytes((u_int8_t *) &holder, pkt, opt.length-2) == 0)
 	return;
-      bytes_read += (length-2);
-      
+      bytes_read = bytes_read + opt.length - 2;
+
+      /*
+       * Do something intelligent with the options that we understand
+       */
+
+      switch(opt.code)
+	{
+	case IP_OPTION_RECORDROUTE:
+	  dump_ip_recordroute(holder, opt.length-2);
+	  break;
+
+	default:
+	  break;
+	}
     }
 }
