@@ -5,7 +5,7 @@
 **
 ** Comments: Functions to handle certain IP protocol numbers
 **
-** $Id: ip_services.c,v 1.11 2001/11/15 00:22:36 mborella Exp $
+** $Id: ip_services.c,v 1.12 2001/11/16 00:10:58 mborella Exp $
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -91,6 +91,9 @@ strmap_t port_map[] =
   { PORT_L2TP,             "L2TP" },
   { PORT_PPTP,             "PPTP" },
 
+  { PORT_RADIUS,           "RADIUS" },
+  { PORT_RADACCOUNT,       "RADIUS accounting" },
+
   { PORT_SIP,              "SIP" },
   { 0, "" }
 };
@@ -191,6 +194,11 @@ service_func_t port2func(u_int16_t port)
 	  f = dump_tftp;
 	  break;
 
+	case PORT_RADIUS:
+	case PORT_RADACCOUNT:
+	  f = dump_radius;
+	  break;
+
 	default:
 	  f = NULL;
 	  break;
