@@ -5,7 +5,7 @@
 **
 ** Comments: IPCP module.
 **
-** $Id: ipcp.c,v 1.5 2001/01/05 19:12:32 mborella Exp $
+** $Id: ipcp.c,v 1.6 2001/05/28 19:24:04 mborella Exp $
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -127,6 +127,9 @@ void dump_ipcp(packet_t *pkt)
 {
   ipcp_t ipcp;
 
+  /* Set the layer */
+  set_layer(LAYER_DATALINK);
+
   /*
    * Get the header
    */
@@ -144,21 +147,18 @@ void dump_ipcp(packet_t *pkt)
    * Dump the header
    */
 
-  if (!my_args->l)
+  if (my_args->m)
     {
-      if (my_args->m)
-	{
-	  display_minimal_string("| IPCP ");
-	  display_minimal_string(map2str(ipcp_code_map, ipcp.code));
-	  display_minimal_string(" ");
-	}
-      else
-	{
-	  display_header_banner("IPCP Header");
-	  display_strmap("Code", ipcp.code, ipcp_code_map);
-	  display("Identifier", &ipcp.identifier, 1, DISP_DEC);
-	  display("Length", (u_int8_t *) &ipcp.length, 2, DISP_DEC);
-	}
+      display_minimal_string("| IPCP ");
+      display_minimal_string(map2str(ipcp_code_map, ipcp.code));
+      display_minimal_string(" ");
+    }
+  else
+    {
+      display_header_banner("IPCP Header");
+      display_strmap("Code", ipcp.code, ipcp_code_map);
+      display("Identifier", &ipcp.identifier, 1, DISP_DEC);
+      display("Length", (u_int8_t *) &ipcp.length, 2, DISP_DEC);
     }
 
   /*
@@ -208,7 +208,7 @@ void dump_ipcp(packet_t *pkt)
                  * and put a comma before all but the first
                  */
 
-                if (my_args->m && !my_args->l)
+                if (my_args->m)
                   {
                     if (comma)
                       display_minimal_string(", ");
@@ -221,17 +221,14 @@ void dump_ipcp(packet_t *pkt)
 		 * Display the type and length
 		 */
 		
-		if (!my_args->l)
+		if (my_args->m)
 		  {
-		    if (my_args->m)
-		      {
-			display_minimal_string(map2str(ipcp_option_map, type));
-		      }
-		    else
-		      {
-			display_strmap("Option", type, ipcp_option_map);
-			display("  Length", &length, 1, DISP_DEC);
-		      }
+		    display_minimal_string(map2str(ipcp_option_map, type));
+		  }
+		else
+		  {
+		    display_strmap("Option", type, ipcp_option_map);
+		    display("  Length", &length, 1, DISP_DEC);
 		  }
 		
 		/*
@@ -249,67 +246,65 @@ void dump_ipcp(packet_t *pkt)
 		     * Display the value
 		     */
 
-		    if (!my_args->l)
+		    switch(type)
 		      {
-			switch(type)
-			  {
-			  case IPCP_OPTION_IPADDRS:
-			    break;
-			    
-			  case IPCP_OPTION_IPCOMPPROTO:
+		      case IPCP_OPTION_IPADDRS:
+			break;
+			
+		      case IPCP_OPTION_IPCOMPPROTO:
+			{
+			  u_int16_t comp_type;
+			  
+			  memcpy((void *) &comp_type, (void *) &value, 2);
+			  comp_type = ntohs(comp_type);
+			  
+			  if (my_args->m)
 			    {
-			      u_int16_t comp_type;
-
-			      memcpy((void *) &comp_type, (void *) &value, 2);
-			      comp_type = ntohs(comp_type);
-			      
-			      if (my_args->m)
-				{
-				  display_minimal_string(" ");
-				  display_minimal_string(map2str
-							 (ipcp_comp_map, 
-							  comp_type));
-				}
-			      else
-				{
-				  u_int8_t max_slot_id = value[2];
-				  u_int8_t comp_slot_id = value[3];
-
-				  display_strmap("IP compression", comp_type, 
-						 ipcp_comp_map);
-				  display("Max slot ID", 
-					  (u_int8_t *) &max_slot_id, 1, 
-					  DISP_DEC);
-				  display("Comp slot ID", 
-					  (u_int8_t *) &comp_slot_id, 1, 
-					  DISP_DEC);
-				}
-			      break;
-			      
-			    case IPCP_OPTION_IPADDR:
-			    case IPCP_OPTION_PRIMARYDNS:
-			    case IPCP_OPTION_PRIMARYNBNS:
-			    case IPCP_OPTION_SECONDARYDNS:
-			    case IPCP_OPTION_SECONDARYNBNS:
-			      if (my_args->m)
-				{
-				  display_minimal_string(" ");
-				  display_minimal_ipv4((u_int8_t *) &value);
-				}
-			      else
-				display_ipv4("IP address", (u_int8_t *) &value);
-			      break;
-			      
+			      display_minimal_string(" ");
+			      display_minimal_string(map2str
+						     (ipcp_comp_map, 
+						      comp_type));
 			    }
-			  }
-		      }
-		  } /* if */
+			  else
+			    {
+			      u_int8_t max_slot_id = value[2];
+			      u_int8_t comp_slot_id = value[3];
+			      
+			      display_strmap("IP compression", comp_type, 
+					     ipcp_comp_map);
+			      display("Max slot ID", 
+				      (u_int8_t *) &max_slot_id, 1, 
+				      DISP_DEC);
+			      display("Comp slot ID", 
+				      (u_int8_t *) &comp_slot_id, 1, 
+				      DISP_DEC);
+			    }
+			  break;
+			}
+
+			case IPCP_OPTION_IPADDR:
+			case IPCP_OPTION_PRIMARYDNS:
+			case IPCP_OPTION_PRIMARYNBNS:
+			case IPCP_OPTION_SECONDARYDNS:
+			case IPCP_OPTION_SECONDARYNBNS:
+			  if (my_args->m)
+			    {
+			      display_minimal_string(" ");
+			      display_minimal_ipv4((u_int8_t *) &value);
+			    }
+			  else
+			    display_ipv4("IP address", (u_int8_t *) &value);
+			  break;
+			  
+			}
+
+		  }
 	      } /* while */
             
 	    /* 
              * Insert end paren in minimal mode
              */
-
+	    
             if (my_args->m)
               display_minimal_string(")");
 	  }
@@ -339,7 +334,7 @@ void dump_ipcp(packet_t *pkt)
 		  }
 	
 		/* dump it out as hex, but don't dump in minimal mode */
-		if (!my_args->l && !my_args->m)
+		if (!my_args->m)
 		  {
 		    display("Data", data, data_len, DISP_HEX);
 		  }
