@@ -5,7 +5,7 @@
 **
 ** Comments: Dump IP header information
 **
-** $Id: ipv6.c,v 1.13 2001/10/11 20:43:50 mborella Exp $
+** $Id: ipv6.c,v 1.14 2002/01/03 00:04:01 mborella Exp $
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -26,6 +26,8 @@
 #include "ipv6.h"
 #include "ip_protocols.h"
 
+#define HOLDER_SIZE 64
+
 /* Structure of IPv6 header */
 typedef struct ipv6_header
 {
@@ -64,7 +66,7 @@ extern strmap_t ipproto_map[];
 void dump_ipv6(packet_t *pkt)
 {
   ipv6_header_t ipv6;
-  char          holder[64];
+  char          holder[HOLDER_SIZE];
   u_int8_t      ver;
   u_int8_t      class; 
   u_int32_t     flow;
@@ -123,7 +125,7 @@ void dump_ipv6(packet_t *pkt)
       display("Flow label", (u_int8_t *) &flow, 4, DISP_HEX);
       display("Payload length", (u_int8_t *) &ipv6.payload_length, 2, 
 	      DISP_DEC);
-      sprintf(holder, "%d (%s)", ipv6.next_header, 
+      snprintf(holder, HOLDER_SIZE, "%d (%s)", ipv6.next_header, 
 	      map2str(ipproto_map, ipv6.next_header));
       display("Next header", holder, strlen(holder), DISP_STRING);
       display("Hop limit", (u_int8_t *) &ipv6.hop_limit, 1, DISP_DEC);
