@@ -13,7 +13,7 @@
 ** and when you can't find the value anywhere else, look in:
 ** draft-ietf-ipsec-ike-01 "The Internet Key Exchange (IKE)"
 **
-** $Id: isakmp.c,v 1.9 2001/03/27 20:45:36 mborella Exp $
+** $Id: isakmp.c,v 1.10 2001/05/28 19:24:04 mborella Exp $
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -892,6 +892,9 @@ void dump_isakmp(packet_t * pkt)
   u_int8_t next;
   u_int8_t e_flag, c_flag, a_flag;
 
+  /* Set the layer */
+  set_layer(LAYER_APPLICATION);
+
   /*
    * Get the main ISAKMP header
    */
