@@ -6,7 +6,7 @@
 **
 ** Comments: Dump L2TP header information
 **
-** $Id: l2tp.c,v 1.9 2001/05/28 19:24:04 mborella Exp $
+** $Id: l2tp.c,v 1.10 2001/10/12 21:45:02 mborella Exp $
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -254,14 +254,16 @@ extern struct arg_t * my_args;
 
 /*----------------------------------------------------------------------------
 **
-** dump_avp()
+** dump_l2tp_avp()
 **
 ** Parse L2TP AVP subheader
 **
+** Returns a -1 on error so that we can fall out of the calling loop.
+**
 **----------------------------------------------------------------------------
 */
 
-void dump_l2tp_avp(packet_t * pkt, u_int16_t *n)
+int dump_l2tp_avp(packet_t * pkt, u_int16_t *n)
 {
   l2tpavp_t avp;
   int8_t m, h, zeros;
@@ -272,7 +274,7 @@ void dump_l2tp_avp(packet_t * pkt, u_int16_t *n)
    */
   
   if (get_packet_bytes((u_int8_t *) &avp, pkt, L2TP_AVP_SIZE) == 0)
-    return;
+    return -1;
   *n = *n + L2TP_AVP_SIZE;
 
   /*
@@ -318,7 +320,7 @@ void dump_l2tp_avp(packet_t * pkt, u_int16_t *n)
       if (get_packet_bytes((u_int8_t *) attribute, pkt, real_length) == 0)
 	{
 	  my_free(attribute);
-	  return;
+	  return -1;
 	}
       *n = *n + real_length;
 
@@ -416,6 +418,8 @@ void dump_l2tp_avp(packet_t * pkt, u_int16_t *n)
       /* free memory */
       my_free(attribute);
     }
+
+  return 0;
 }
 
 
@@ -618,7 +622,8 @@ void dump_l2tp(packet_t *pkt)
     {
       /* grab all of the avp's, one by one */
       while(bytes_read < length)
-	dump_l2tp_avp(pkt, &bytes_read);
+	if (dump_l2tp_avp(pkt, &bytes_read) == -1)
+	  break;
       
       /* dump the hex buffer */
       hexbuffer_flush();
