@@ -90,6 +90,8 @@ strmap_t mobileip_type_map[] =
 #define MOBILEIP_EXT_CVSE              38 /* RFC 3025 */
 #define MOBILEIP_EXT_SESSIONSPECIFIC   39 /* TIA/IS-2001 */
 #define MOBILEIP_EXT_REGUPDATEAUTH     40 /* TIA/IS-2001 */
+#define MOBILEIP_EXT_NAI               131 /* RFC 2794 */
+#define MOBILEIP_EXT_MNFACHALLENGE     132 /* RFC 2794 */
 
 /* 
  * Mobile IP extension map
@@ -104,6 +106,8 @@ strmap_t mobileip_ext_map [] =
   { MOBILEIP_EXT_CVSE,            "critical vendor-specific extension" },
   { MOBILEIP_EXT_SESSIONSPECIFIC, "session specific extension" },
   { MOBILEIP_EXT_REGUPDATEAUTH,   "registration update authentication" },
+  { MOBILEIP_EXT_NAI,             "network access identifier" },
+  { MOBILEIP_EXT_MNFACHALLENGE,   "MN-FA challenge" },
   { 0, "" }
 };
 
@@ -271,6 +275,18 @@ typedef struct mobileip_ext_mhauth
   u_int32_t   spi;
 } mobileip_ext_mhauth_t;
 
+/*
+ * Structure of the fixed portion of the general mobile IP auth extension
+ */
+
+typedef struct mobileip_ext_genmobileipauth
+{
+  u_int8_t    type;
+  u_int8_t    subtype;
+  u_int16_t   length;
+  u_int32_t   spi;
+} mobileip_ext_genmobileipauth_t;
+
 extern struct arg_t * my_args;
 extern strmap_t ethertype_map[];
 
@@ -407,6 +423,146 @@ void dump_mobileip_ext_cvse(packet_t * pkt)
     }
 }
 
+/*----------------------------------------------------------------------------
+**
+** dump_mobileip_ext_nai()
+**
+** Dumps mobile IP NAI extension
+**
+**----------------------------------------------------------------------------
+*/
+
+void dump_mobileip_ext_nai(packet_t * pkt)
+{
+  u_int8_t    type;
+  u_int8_t    length;
+  char *      nai;
+  
+  /* Get the type */
+  if (get_packet_bytes((u_int8_t *) &type, pkt, 1) == 0)
+    return;
+
+  /* Get the length */
+  if (get_packet_bytes((u_int8_t *) &length, pkt, 1) == 0)
+    return;
+ 
+  /* Get the NAI */
+  nai = (char *) malloc (length+2);
+  if (get_packet_bytes(nai, pkt, length) == 0)
+    return;
+  nai[length] = '\0';
+  
+  /* Display */
+  if (my_args->m)
+    {
+    }
+  else
+    {
+      display_strmap("Extension type", type, mobileip_ext_map);
+      display("  Length", (u_int8_t *) &length, 1, DISP_DEC);
+      display_string("  NAI", nai);
+    }
+
+  /* Free memory */
+  my_free(nai);
+ 
+  return;
+}
+
+/*----------------------------------------------------------------------------
+**
+** dump_mobileip_ext_mnfachallenge()
+**
+** Dumps mobile IP MN-FA  extension
+**
+**----------------------------------------------------------------------------
+*/
+
+void dump_mobileip_ext_mnfachallenge(packet_t * pkt)
+{
+  u_int8_t    type;
+  u_int8_t    length;
+  u_int8_t *  challenge;
+  
+  /* Get the type */
+  if (get_packet_bytes((u_int8_t *) &type, pkt, 1) == 0)
+    return;
+
+  /* Get the length */
+  if (get_packet_bytes((u_int8_t *) &length, pkt, 1) == 0)
+    return;
+ 
+  /* Get the authenticator */
+  challenge = (char *) malloc (length+2);
+  if (get_packet_bytes((u_int8_t *) challenge, pkt, length) == 0)
+    return;
+  
+  /* Display */
+  if (my_args->m)
+    {
+    }
+  else
+    {
+      display_strmap("Extension type", type, mobileip_ext_map);
+      display("  Length", (u_int8_t *) &length, 1, DISP_DEC);
+      display("  Challenge", (u_int8_t *) challenge, length, DISP_HEX);
+    }
+
+  /* Free memory */
+  my_free(challenge);
+ 
+  return;
+}
+
+
+/*----------------------------------------------------------------------------
+**
+** dump_mobileip_ext_genmobileipauth()
+**
+** Dumps the general MIP authentication extension
+**
+**----------------------------------------------------------------------------
+*/
+
+void dump_mobileip_ext_genmobileipauth(packet_t * pkt)
+{
+  mobileip_ext_genmobileipauth_t  genmip;
+  u_int8_t *                      auth;
+
+  /* Get the fixed header */
+  if (get_packet_bytes((u_int8_t *) &genmip, pkt, 8) == 0)
+   return;
+
+  /* Conversions */
+  genmip.length = ntohs(genmip.length);
+
+  /* Allocate memory for the authentication */
+  auth = my_malloc(genmip.length-4);
+
+  /* Get the authenticator */
+  if (get_packet_bytes(auth, pkt, genmip.length-4) == 0)
+    return;
+
+  /* Display */
+  if (my_args->m)
+    {
+    }
+  else
+    {
+      display_strmap("Extension type", genmip.type, mobileip_ext_map);
+      display("  Subtype", &genmip.subtype, 1, DISP_DEC);
+      display("  Length", (u_int8_t *) &genmip.length, 2, DISP_DEC);
+      display("  SPI", (u_int8_t *) &genmip.spi, 4, DISP_HEX);
+      display("  Authenticator", auth, genmip.length-4, DISP_HEX_MULTILINE);
+    }
+
+  /* Free memory for authenticator */
+  my_free(auth);
+
+  return;
+
+}
+
 /*----------------------------------------------------------------------------
 **
 ** dump_mobileip_ext_mhauth()
@@ -445,7 +601,7 @@ void dump_mobileip_ext_mhauth(packet_t * pkt)
     {
       display_strmap("Extension type", mh.type, mobileip_ext_map);
       display("  Length", &mh.length, 1, DISP_DEC);
-      display("  SPI", (u_int8_t *) &mh.spi, 4, DISP_DEC);
+      display("  SPI", (u_int8_t *) &mh.spi, 4, DISP_HEX);
       display("  Authenticator", authenticator, mh.length-4, 
 	      DISP_HEX_MULTILINE);
     }
@@ -672,6 +828,18 @@ void dump_mobileip(packet_t *pkt)
 	  dump_mobileip_ext_mhauth(pkt);
 	  break;
 
+        case MOBILEIP_EXT_NAI:
+          dump_mobileip_ext_nai(pkt);
+          break;
+ 
+        case MOBILEIP_EXT_MNFACHALLENGE:
+          dump_mobileip_ext_mnfachallenge(pkt);
+          break;
+
+        case MOBILEIP_EXT_GENMOBILEIPAUTH:
+          dump_mobileip_ext_genmobileipauth(pkt);
+          break;
+
 	default: /* We don't recognize this extension...just dump the data */
 	  {
 	    u_int8_t   type;
@@ -700,7 +868,10 @@ void dump_mobileip(packet_t *pkt)
 
 	    /* Get the data */
 	    if (get_packet_bytes(data, pkt, length) == 0)
-	      return;
+              {
+                hexbuffer_flush();
+	        return;
+              } 
 
 	    /* 
 	     * Dump the data. Let's not do anything for minimal mode because
