@@ -5,7 +5,7 @@
 **
 ** Comments: Dump packet payload
 **
-** $Id: payload.c,v 1.8 2001/09/07 22:50:31 mborella Exp $
+** $Id: payload.c,v 1.9 2001/11/15 00:22:36 mborella Exp $
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -28,6 +28,8 @@
 
 #define PAYLOAD_SIZE  1500
 
+extern struct arg_t * my_args;
+
 /*----------------------------------------------------------------------------
 **
 ** dump_payload()
@@ -42,6 +44,10 @@ void dump_payload(packet_t *pkt)
   char   holder[PAYLOAD_SIZE];
   int    bytes;
 
+  /* Quit if we're in minimal mode */
+  if (my_args->m)
+    return;
+
   /* Set the layer */
   set_layer(LAYER_APPLICATION);
 
