@@ -307,6 +307,10 @@ void dump_ppp_hdlc(packet_t * pkt)
 	  holder_after[ptr] = holder_before[i] ^ 0x20;
 	  ptr++;
 	}
+    
+      /* Bail out when we see a 0x7e that is not at the beginning */
+      if (i>0 && holder_before[i] == 0x7e)
+        break;
     }
   
   /* Delete the before data, we no longer need it */
