@@ -5,7 +5,7 @@
 **
 ** Comments: 
 **
-** $Id: rsvp.c,v 1.2 2001/04/02 17:41:01 mborella Exp $
+** $Id: rsvp.c,v 1.3 2001/05/28 19:24:04 mborella Exp $
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -70,6 +70,9 @@ void dump_rsvp(packet_t *pkt)
   u_int8_t version;
   u_int8_t flags;
 
+  /* Set the layer */
+  set_layer(LAYER_APPLICATION);
+
   /* Stats accounting */
   stats_update(STATS_IP);
 
@@ -84,23 +87,20 @@ void dump_rsvp(packet_t *pkt)
   rsvp.length = ntohs(rsvp.length);
 
   /* Dump the fields */
-  if (!my_args->n)
+  if (!my_args->m)
     {
-      if (!my_args->m)
-	{
-	  display_header_banner("RSVP Header");
-
-	  display("Version", (u_int8_t *) &version, 1, DISP_DEC);
-	  display("Flags", (u_int8_t *) &flags, 1, DISP_HEX);
-	  display_strmap("Message type", rsvp.msg_type, rsvp_msgtype_map);
-	  display("Checksum", (u_int8_t *) &rsvp.checksum, 2, DISP_DEC);
-	  display("Send TTL", (u_int8_t *) &rsvp.send_ttl, 1, DISP_DEC);
-	  display("Reserved", (u_int8_t *) &rsvp.reserved, 1, DISP_DEC);
-	  display("Length", (u_int8_t *) &rsvp.length, 2, DISP_DEC);
-	}
-      else
-	{
-
-	}
+      display_header_banner("RSVP Header");
+      
+      display("Version", (u_int8_t *) &version, 1, DISP_DEC);
+      display("Flags", (u_int8_t *) &flags, 1, DISP_HEX);
+      display_strmap("Message type", rsvp.msg_type, rsvp_msgtype_map);
+      display("Checksum", (u_int8_t *) &rsvp.checksum, 2, DISP_DEC);
+      display("Send TTL", (u_int8_t *) &rsvp.send_ttl, 1, DISP_DEC);
+      display("Reserved", (u_int8_t *) &rsvp.reserved, 1, DISP_DEC);
+      display("Length", (u_int8_t *) &rsvp.length, 2, DISP_DEC);
+    }
+  else
+    {
+      
     }
 }
