@@ -5,7 +5,7 @@
 **
 ** Comments: Utility functions for general use
 **
-** $Id: utilities.h,v 1.4 2001/09/07 22:50:31 mborella Exp $
+** $Id: utilities.h,v 1.5 2001/11/15 00:22:36 mborella Exp $
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -35,5 +35,7 @@ inline char * argv2str(char **);
 inline void * my_malloc(size_t);
 inline void   my_free(void *);
 inline void   dump_hex_and_text(char *, int);
+inline int    ipaddr_space(u_int32_t);
+inline char * make_space_str(int);
 
 #endif
